==> ask-cli-2.14.0.tgz: package/.github/ISSUE_TEMPLATE/issue-report.md <==
---
name: Issue report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

<!--
PLEASE HELP US PROCESS GITHUB ISSUES FASTER BY PROVIDING THE FOLLOWING INFORMATION.
ISSUES MISSING IMPORTANT INFORMATION MAY BE CLOSED WITHOUT INVESTIGATION.
-->

## I'm submitting a...
<!-- Check one of the following options with "x" -->
<pre><code>
[ ] Regression (a behavior that used to work and stopped working in a new release)
[ ] Bug report  <!-- Please search GitHub for a similar issue or PR before submitting -->
[ ] Performance issue
[ ] Feature request
[ ] Documentation issue or request
[ ] Other... Please describe:
</code></pre>

<!--- Provide a general summary of the issue in the Title above -->

## Expected Behavior
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

## Current Behavior
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- Include full errors, uncaught exceptions, stack traces, and relevant logs. Remember to use --debug to get the full context -->
<!--- If service responses are relevant, please include any -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

**CLI Snapshot**
If applicable, add screenshots to help explain your problem.

## Steps to Reproduce (for bugs)
<!--- Provide a self-contained, concise snippet of code -->
<!--- For more complex issues provide a repo with the smallest sample that reproduces the bug -->
<!--- Including business logic or unrelated code makes diagnosis more difficult -->

## Possible Solution
<!--- Not required, but suggest a fix/reason for the bug -->
<!--- or ideas how to implement the addition or change -->

## Your Environment and Context
<!--- Include as many relevant details about the environment where the bug was discovered -->
* ask-cli version: x.x.x
* Operating System and version:
* Node.js version used for development:
* NPM version used for development:

==> ask-cli-2.16.2.tgz: package/.github/ISSUE_TEMPLATE/issue-report.md <==
---
name: Issue report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

<!--
PLEASE HELP US PROCESS GITHUB ISSUES FASTER BY PROVIDING THE FOLLOWING INFORMATION.
ISSUES MISSING IMPORTANT INFORMATION MAY BE CLOSED WITHOUT INVESTIGATION.
-->

## I'm submitting a...
<!-- Check one of the following options with "x" -->
<pre><code>
[ ] Regression (a behavior that used to work and stopped working in a new release)
[ ] Bug report  <!-- Please search GitHub for a similar issue or PR before submitting -->
[ ] Performance issue
[ ] Feature request
[ ] Documentation issue or request <!-- If the issue with  https://developer.amazon.com/en-US/docs/alexa, please use the feedback button to send your feedback. -->
[ ] Other... Please describe: <!-- Please try first searching https://forums.developer.amazon.com for general questions. -->
</code></pre>

<!--- Provide a general summary of the issue in the Title above -->

## Expected Behavior
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

## Current Behavior
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- Include full errors, uncaught exceptions, stack traces, and relevant logs. Remember to use --debug to get the full context -->
<!--- If service responses are relevant, please include any -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

**CLI Snapshot**
If applicable, add screenshots to help explain your problem.

## Steps to Reproduce (for bugs)
<!--- Provide a self-contained, concise snippet of code -->
<!--- For more complex issues provide a repo with the smallest sample that reproduces the bug -->
<!--- Including business logic or unrelated code makes diagnosis more difficult -->

## Possible Solution
<!--- Not required, but suggest a fix/reason for the bug -->
<!--- or ideas how to implement the addition or change -->

## Your Environment and Context
<!--- Include as many relevant details about the environment where the bug was discovered -->
* ask-cli version: x.x.x
* Operating System and version:
* Node.js version used for development:
* NPM version used for development:
